@@ -3,8 +3,8 @@ from .chibi_csv import Chibi_csv
 from .chibi_yaml import Chibi_yaml
 from .chibi_json import Chibi_json
 from .chibi_python import Chibi_python
-from .chibi_systemd import Chibi_systemd # NOQA
-from .conf import Chibi_conf # NOQA
+from .chibi_systemd import Chibi_systemd  # noqa: F401
+from .conf import Chibi_conf  # noqa: F401
 
 
 __all__ = [ 'Chibi_csv', 'Chibi_yaml', 'Chibi_json', 'Chibi_python' ]
