@@ -324,8 +324,10 @@ def __remove_element__list( l, element ):
             continue
         if isinstance( i, list ):
             result.append( __remove_element__list( i, element ) )
-        if isinstance( i, dict ):
+        elif isinstance( i, dict ):
             result.append( remove_value( i, element ) )
+        else:
+            result.append( i )
 
     return result
 
@@ -358,3 +360,33 @@ def split( d ):
     [ { "a": "1" }, { "b": "2" } ]
     """
     return map( lambda x: { x[0]: x[1] }, d.items() )
+
+
+def group_by( d, key ):
+    from chibi.atlas.multi import Chibi_atlas_multi
+    result = Chibi_atlas_multi()
+    if isinstance( d, dict ):
+        try:
+            result[ d[ key ] ] = d
+        except KeyError:
+            pass
+    elif isinstance( d, list ):
+        for dd in d:
+            r = group_by( dd, key )
+            result.update( r )
+    return result
+
+
+def search_value( d, value ):
+    if isinstance( d, dict ):
+        for k, v in d.items():
+            if v == value:
+                return k
+            in_search = search_value( v, value )
+            if in_search:
+                return f"{k}__{in_search}"
+    elif isinstance( d, list ):
+        for i, dd in enumerate( d ):
+            in_search = search_value( dd, value )
+            if in_search:
+                return f"[{i}]__{in_search}"
